@@ -1,8 +1,9 @@
 from .base import Service
-from .decorators import task, requirements
+from .decorators import task, requirements, listener
 
 __all__ = (
     'Service',
     'task',
     'requirements',
+    'listener',
 )
